@@ -290,6 +290,16 @@ func (v *wm) EnableZoneDetected(flags dbus.Flags, val bool) error {
 	return (<-v.GoEnableZoneDetected(flags, make(chan *dbus.Call, 1), val).Done).Err
 }
 
+// method SetDecorationDeepinTheme
+
+func (v *wm) GoSetDecorationDeepinTheme(flags dbus.Flags, ch chan *dbus.Call, deepinThemeName string) *dbus.Call {
+	return v.GetObject_().Go_(v.GetInterfaceName_()+".SetDecorationDeepinTheme", flags, ch, deepinThemeName)
+}
+
+func (v *wm) SetDecorationDeepinTheme(flags dbus.Flags, deepinThemeName string) error {
+	return (<-v.GoSetDecorationDeepinTheme(flags, make(chan *dbus.Call, 1), deepinThemeName).Done).Err
+}
+
 // signal WorkspaceBackgroundChanged
 
 func (v *wm) ConnectWorkspaceBackgroundChanged(cb func(index int32, newUri string)) (dbusutil.SignalHandlerId, error) {
@@ -342,3 +352,47 @@ func (v *wm) ConnectStartupReady(cb func(wm_name string)) (dbusutil.SignalHandle
 
 	return obj.ConnectSignal_(rule, sigRule, handlerFunc)
 }
+
+// signal compositingEnabledChanged
+
+func (v *wm) ConnectCompositingEnabledChanged(cb func(enabled bool)) (dbusutil.SignalHandlerId, error) {
+	if cb == nil {
+		return 0, errors.New("nil callback")
+	}
+	obj := v.GetObject_()
+	rule := fmt.Sprintf(
+		"type='signal',interface='%s',member='%s',path='%s',sender='%s'",
+		v.GetInterfaceName_(), "compositingEnabledChanged", obj.Path_(), obj.ServiceName_())
+
+	sigRule := &dbusutil.SignalRule{
+		Path: obj.Path_(),
+		Name: v.GetInterfaceName_() + ".compositingEnabledChanged",
+	}
+	handlerFunc := func(sig *dbus.Signal) {
+		var enabled bool
+		err := dbus.Store(sig.Body, &enabled)
+		if err == nil {
+			cb(enabled)
+		}
+	}
+
+	return obj.ConnectSignal_(rule, sigRule, handlerFunc)
+}
+
+// property compositingEnabled b
+
+func (v *wm) CompositingEnabled() proxy.PropBool {
+	return proxy.PropBool{
+		Impl: v,
+		Name: "compositingEnabled",
+	}
+}
+
+// property compositingPossible b
+
+func (v *wm) CompositingPossible() proxy.PropBool {
+	return proxy.PropBool{
+		Impl: v,
+		Name: "compositingPossible",
+	}
+}
